@@ -3,7 +3,7 @@ import enum
 
 class JobCategory(enum.IntEnum):
     warrior = 0
-    mage = 1
+    magician = 1
     archer = 2
     thief = 3
     pirate = 4
